@@ -30,6 +30,7 @@ sub new_ftpssl
 		{
 			my $cwd = $xftp->{xftp}->pwd();
 			$xftp->{cwd} = $cwd  if ($cwd);
+			$xftp->{protocol} = 'Net::FTPSSL';
 			return $xftp;
 		}
 	}
@@ -41,6 +42,11 @@ sub new_ftpssl
 	return undef;
 }
 
+sub protocol
+{
+	return shift->{protocol};
+}
+
 {
 	no warnings 'redefine';
 	sub cwd  #SET THE "CURRENT" DIRECTORY.
