@@ -54,6 +54,7 @@ sub new_foreign
 			$xftp->{xftp_lastmsg} = $xftp->{xftp}->error;
 			$xftp->{xftp_lastmsg} .= ' ' . $errORwarn  if ($errORwarn);
 			$@ = $xftp->{xftp_lastmsg};
+			$xftp->{protocol} = 'Net::SFTP::Foreign';
 			return undef;
 		}
 		return $xftp;
@@ -61,6 +62,11 @@ sub new_foreign
 	return undef;
 }
 
+sub protocol
+{
+	return shift->{protocol};
+}
+
 {
 	no warnings 'redefine';
 	sub cwd  #SET THE "CURRENT" DIRECTORY.
